<?php
/* -----------------------------------------------------------------------------
 * Extra Settings in Settings > Design Settings Page
 * -------------------------------------------------------------------------- */
add_action('admin_enqueue_scripts', 'dominion_custom_admin_css'); // add css to admin page
function dominion_custom_admin_css() {
	wp_enqueue_style( 'dominion-animations-new', plugins_url( 'the_dominion/modules/css/dominion-admin-style.css' ) );
}

add_action('admin_menu', 'dominion_about_settings_submenu_page');
function dominion_about_settings_submenu_page() {
    add_submenu_page(
        'options-general.php',
        'Dominion Domain Checker',
        'Dominion Domain Checker',
        'manage_options',
        'dominion-about',
        'dominion_about_submenu_page_callback' );
}

function dominion_about_submenu_page_callback() {

//must check that the user has the required permission 
    if (!current_user_can('manage_options'))
    {
      wp_die( esc_html__('You do not have sufficient permissions to access this page.', 'dominion') );
    }

    // variables for the field and option names 
    $data_field_name = 'bootstrap_switch';

    // Read in existing option value from database
    $design_opt_val = get_option( $data_field_name );

    if( isset($_POST[ $data_field_name ])) {
        // Read their posted value
        $design_opt_val = $_POST[ $data_field_name ];

        // Save the posted value in the database
        update_option( $data_field_name, $design_opt_val );

        // Put a "settings saved" message on the screen
?>
<div class="updated">
	<p><strong><?php esc_html_e('Settings saved.', 'dominion' ); ?></strong></p>
</div>
<?php } ?>
<div class="wrap panto-page-welcome about-wrap">
	<h1 class="title"><?php echo sprintf( esc_html__( 'Welcome to Dominion - Version %s', 'dominion' ), preg_replace( '/^(\d+)(\.\d+)?(\.\d)?/', '$1$2', DOMINION_PLUGIN_VERSION ) ) ?></h1>
	<div class="about-text"><?php esc_html_e('Congratulations! You are about to use most powerful plugin for Domain Checker.', 'dominion') ?></div>
	<div class="wp-badge vc-page-logo"><?php esc_html_e('Version ', 'dominion');?><?php echo DOMINION_PLUGIN_VERSION; ?></div>
	<hr />
	<form method="post" action="">
		<p class="p_radio_options">
		<input type="radio" name="<?php echo esc_attr($data_field_name); ?>" value="<?php esc_attr_e('bootstrap_on', 'dominion'); ?>" <?php if($design_opt_val=='bootstrap_on'){echo 'checked';} ?>> <?php echo esc_html_e('Bootstrap ON', 'dominion'); ?><br>
		<input type="radio" name="<?php echo esc_attr($data_field_name); ?>" value="<?php esc_attr_e('bootstrap_off', 'dominion'); ?>" <?php if(($design_opt_val=='bootstrap_off') || (!$design_opt_val)){echo 'checked';} ?>> <?php echo esc_html_e('Bootstrap OFF (Default)', 'dominion'); ?>
		</p>

		<p class="submit">
		<input type="submit" name="Submit" class="button-primary" value="<?php esc_attr_e('Save Changes', 'dominion') ?>" />
		</p>
		<div class="clear"></div>
	</form>
	<p class="notes"><?php esc_html_e('You should switch off the Bootstrap, if your theme has Bootstrap already.', 'dominion') ?></p>

<div class="row" style="margin-bottom:50px;">
  <div class="col-md-6">
    <div class="boxed-content">
		<h3><?php esc_html_e('How to get started (with WPBakery plugin installed)', 'dominion');?></h3>
		<p><?php _e('1. Navigate to <strong>WP-Admin > Pages > Add New</strong> and click on the <strong>WPBakery Page Builder</strong> button.', 'dominion');?><br>
		<?php _e('2. Click on the <strong>Backend Editor</strong>, then click on the <strong>Add Element</strong> button.', 'dominion');?><br>
		<?php _e('3. You will get an window with few tabs, from there click on the <strong>by Fluent-Themes Shortcodes</strong> tab.', 'dominion');?><br>
		<?php _e('4. You will find all the elements/layouts there; just click on your chosen layout.', 'dominion');?><br>
		<?php _e('5. Now you will find the settings fields to design your Domain Checker form as your needs.', 'dominion');?><br>
		<?php _e('6. After completing the settings click on <strong>Save Changes</strong> button and <strong>Publish</strong> the page.', 'dominion');?></p>
	</div>
  </div>
  <div class="col-md-6">
    <div class="boxed-content">
		<h3><?php esc_html_e('How to get started (without WPBakery plugin installed)', 'dominion');?></h3>
		<p><?php _e("1. Navigate to <strong>'WP-Admin > Pages > Add New'</strong> and add the <strong>'Shortcode'</strong> block of your Gutenberg editor.", "dominion");?><br>
		<?php _e('2. You will get a field to insert your shortcode. Insert shortcode like the example below:', 'dominion');?>
		</p>
		<code><?php _e('[dominion_shortcodes_domain_search_6 title="Find your desired domain" search_pholder="Enter your Domain Name" button_label="Search"]', 'dominion');?></code>
		<p><?php _e('Here <code>title</code>, <code>search_pholder</code> and <code>button_label</code> are parameters of the shortcode. You can change the values of the parameters as you need. There are more parameters to use in the shortcode. You can find the <a href="https://fluentthemes.com/wp-plugins/dominion-doc/#all_shortcodes" target="_blank">list of all the parameters here</a>', 'dominion');?>.</p>
	</div>
  </div>
</div>
</div>
<?php
}